***************
Citing Elephant
***************
To refer to the Elephant software package in publications, please use:

Elephant (`doi:10.5281/zenodo.1186602 <https://doi.org/10.5281/zenodo.1186602>`_;
`RRID:SCR_003833 <https://scicrunch.org/resolver/RRID:SCR_003833>`_)

To cite a specific version of Elephant please see version-specific DOIs at:

 `doi:10.5281/zenodo.1186602 <https://doi.org/10.5281/zenodo.1186602>`_

To cite Elephant, please use:

**Denker M, Yegenoglu A, Grün S (2018) Collaborative HPC-enabled workflows on
the HBP Collaboratory using the Elephant framework. Neuroinformatics 2018, P19.
doi:10.12751/incf.ni2018.0019**

A BibTeX entry for LaTeX users is:

.. code-block:: none

    @conference{elephant18,
        author = {Denker, M. and Yegenoglu, A. and Grün, S.},
        booktitle = {Neuroinformatics 2018},
        title = {{C}ollaborative {HPC}-enabled workflows on the {HBP} {C}ollaboratory using the {E}lephant framework},
        pages = {P19},
        year = {2018},
        doi = {10.12751/incf.ni2018.0019},
        url = {https://abstracts.g-node.org/conference/NI2018/abstracts#/uuid/023bec4e-0c35-4563-81ce-2c6fac282abd},
    }


Further publications directly related to Elephant development
:cite:`citations-Rostami17_3,citations-Stella19_104022` (see a list of full
`BibTex references <https://github.com/NeuralEnsemble/elephant/blob/master/doc/bib/elephant.bib>`_
used in Elephant documentation).

.. bibliography::
    :keyprefix: citations-
